pub enum ControllerError {
InterfaceNotFound,
InterfaceNotSupported,
NeighborNotFound,
InvalidIpAddress,
MacAddressNotUnicast,
LinkAddressUnknown,
// some variants omitted
}Expand description
Errors associated with the neighbor table Controller protocol.
Variants
InterfaceNotFound
The specified interface does not exist.
InterfaceNotSupported
The specified interface does not keep a neighbor table (e.g. point-to-point links).
NeighborNotFound
The specified neighbor does not exist in the provided interface’s neighbor table.
InvalidIpAddress
The provided IP address is not a valid neighbor address.
MacAddressNotUnicast
The provided MAC address is not a unicast MAC address.
LinkAddressUnknown
A probe cannot be manually triggered against the specified neighbor because its link address is not known.
Implementations
Sourceimpl ControllerError
impl ControllerError
pub fn from_primitive(prim: u32) -> Option<ControllerError>
pub fn from_primitive_allow_unknown(prim: u32) -> ControllerError
pub fn unknown() -> ControllerError
pub const fn into_primitive(self) -> u32
pub fn is_unknown(&self) -> bool