pub enum ControllerRequest {
AddEntry {
interface: u64,
neighbor: IpAddress,
mac: MacAddress,
responder: ControllerAddEntryResponder,
},
ProbeEntry {
interface: u64,
neighbor: IpAddress,
responder: ControllerProbeEntryResponder,
},
RemoveEntry {
interface: u64,
neighbor: IpAddress,
responder: ControllerRemoveEntryResponder,
},
ClearEntries {
interface: u64,
ip_version: IpVersion,
responder: ControllerClearEntriesResponder,
},
}Expand description
Modify the neighbor table.
Variants
AddEntry
Create a static entry. If a conflict is found, overwrite the existing entry. Conflicts occur when two entries have the same interface identifier and IP address.
- request
interfaceidentifier for the interface used for communicating with the neighbor. - request
neighborIP address of the neighbor. - request
macMAC address of the neighbor.
ProbeEntry
Probe the reachability of an entry in the neighbor table.
If the entry is static it will be converted into a dynamic entry and may eventually be discarded if no longer in active use.
- request
interfaceidentifier for the interface used for communicating with the neighbor. - request
neighborIP address of the neighbor.
RemoveEntry
Delete a dynamic or static entry.
- request
interfaceidentifier for the interface associated with the entry to be deleted. - request
neighborIP address of the entry to be deleted.
ClearEntries
Delete all dynamic and static entries belonging to an interface.
- request
interfaceidentifier for the interface associated with the entries to be deleted. - request
ip_versionthe IP version to clear entries from.
Implementations
Sourceimpl ControllerRequest
impl ControllerRequest
pub fn into_add_entry( self, ) -> Option<(u64, IpAddress, MacAddress, ControllerAddEntryResponder)>
pub fn into_probe_entry( self, ) -> Option<(u64, IpAddress, ControllerProbeEntryResponder)>
pub fn into_remove_entry( self, ) -> Option<(u64, IpAddress, ControllerRemoveEntryResponder)>
pub fn into_clear_entries( self, ) -> Option<(u64, IpVersion, ControllerClearEntriesResponder)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL