EntryIteratorItem

Enum EntryIteratorItem 

pub enum EntryIteratorItem {
    Existing(Entry),
    Idle(IdleEvent),
    Added(Entry),
    Changed(Entry),
    Removed(Entry),
}

Variants



Existing(Entry)

An existing entry in the neighbor table. Does not indicate that an event occurred.



Idle(IdleEvent)

Empty event for indicating there are no more [EntryIteratorItem.existing] items to yield.



Added(Entry)

Event indicating a new entry has been added to the neighbor table.



Changed(Entry)

Event indicating an entry has changed.



Removed(Entry)

Event indicating an entry has been removed from the neighbor table.

Implementations